==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/CreationSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.ModelInstSet;
import io.ciera.tool.sql.architecture.classes.impl.ModelInstSetImpl;
import io.ciera.tool.sql.architecture.expression.Creation;
import io.ciera.tool.sql.architecture.expression.CreationSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreationSetImpl extends InstanceSet<CreationSet,Creation> implements CreationSet {

    // attributes
    @Override
    public void setName( String ref_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setName( ref_name );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( Creation creation : this ) creation.setExpression_number( ref_expression_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setParent_name( ref_parent_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( Creation creation : this ) creation.setBlock_number( ref_block_number );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setClass_name( ref_class_name );
    }
    @Override
    public void setComp_name( String ref_comp_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setComp_name( ref_comp_name );
    }
    @Override
    public void setClass_package( String ref_class_package ) throws XtumlException {
        for ( Creation creation : this ) creation.setClass_package( ref_class_package );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( Creation creation : this ) creation.setParent_package( ref_parent_package );
    }
    @Override
    public void setComp_package( String ref_comp_package ) throws XtumlException {
        for ( Creation creation : this ) creation.setComp_package( ref_comp_package );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( Creation creation : this ) creation.setStatement_number( ref_statement_number );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Creation creation : this ) expressionset.add( creation.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public ModelInstSet R780_creates_ModelInst() throws XtumlException {
        ModelInstSet modelinstset = new ModelInstSetImpl();
        for ( Creation creation : this ) modelinstset.add( creation.R780_creates_ModelInst() );
        return modelinstset;
    }


    @Override
    public Creation nullElement() {
        return CreationImpl.EMPTY_CREATION;
    }

    @Override
    public CreationSet emptySet() {
      return new CreationSetImpl();
    }

    @Override
    public CreationSet value() {
        return this;
    }

    @Override
    public List<Creation> elements() {
        Creation[] elements = toArray(new Creation[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/CreationSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.ModelInstSet;
import io.ciera.tool.sql.architecture.classes.impl.ModelInstSetImpl;
import io.ciera.tool.sql.architecture.expression.Creation;
import io.ciera.tool.sql.architecture.expression.CreationSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreationSetImpl extends InstanceSet<CreationSet,Creation> implements CreationSet {

    public CreationSetImpl() {
    }

    public CreationSetImpl(Comparator<? super Creation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( Creation creation : this ) creation.setBlock_number( ref_block_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( Creation creation : this ) creation.setStatement_number( ref_statement_number );
    }
    @Override
    public void setComp_package( String ref_comp_package ) throws XtumlException {
        for ( Creation creation : this ) creation.setComp_package( ref_comp_package );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setParent_name( ref_parent_name );
    }
    @Override
    public void setClass_package( String ref_class_package ) throws XtumlException {
        for ( Creation creation : this ) creation.setClass_package( ref_class_package );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( Creation creation : this ) creation.setParent_package( ref_parent_package );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( Creation creation : this ) creation.setExpression_number( ref_expression_number );
    }
    @Override
    public void setClass_name( String ref_class_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setClass_name( ref_class_name );
    }
    @Override
    public void setComp_name( String ref_comp_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setComp_name( ref_comp_name );
    }
    @Override
    public void setName( String ref_name ) throws XtumlException {
        for ( Creation creation : this ) creation.setName( ref_name );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Creation creation : this ) expressionset.add( creation.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public ModelInstSet R780_creates_ModelInst() throws XtumlException {
        ModelInstSet modelinstset = new ModelInstSetImpl();
        for ( Creation creation : this ) modelinstset.add( creation.R780_creates_ModelInst() );
        return modelinstset;
    }


    @Override
    public Creation nullElement() {
        return CreationImpl.EMPTY_CREATION;
    }

    @Override
    public CreationSet emptySet() {
      return new CreationSetImpl();
    }

    @Override
    public CreationSet emptySet(Comparator<? super Creation> comp) {
      return new CreationSetImpl(comp);
    }

    @Override
    public CreationSet value() {
        return this;
    }

    @Override
    public List<Creation> elements() {
        Creation[] elements = toArray(new Creation[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
